@@ -29,10 +29,13 @@ createDataPartition <- function (y, times = 1, p = 0.5, list = TRUE, groups = mi
       }
     }
   }
+  
   if (!list)
     {
       out <- matrix(unlist(out), ncol = times)
-      names(out) <- prettySeq(out)
+      colnames(out) <- caret:::prettySeq(1:ncol(out))
+    } else {
+      names(out) <- caret:::prettySeq(out)
     }
   out
 }
