@@ -926,133 +926,3 @@ dotplot.diff.resamples <- function(x, data = NULL, metric = x$metric[1], ...)
             ...)
   }
 
-
-if(FALSE)
-  {
-
-    library(caret)
-    data(BloodBrain)
-
-
-
-    set.seed(1)
-    tmp <- createDataPartition(logBBB,
-                               p = .8,
-                               times = 5)
-    
-    bbbDescr2 <- scale(bbbDescr[, apply(bbbDescr, 2, function(x) length(unique(x)) > 1)])
-
-    ctrl <- trainControl(method = "LGOCV", index = tmp, timingSamps = 100)
-
-    rpartFit <- train(bbbDescr, logBBB,
-                      "rpart", 
-                      tuneLength = 16,
-                      trControl = ctrl)
-
-
-    ctreeFit <- train(bbbDescr, logBBB,
-                      "ctree2",
-                      tuneLength = 5,
-                      trControl = ctrl)
-
-    m5Fit <- train(bbbDescr, logBBB,
-                   "M5Rules",
-                   trControl = ctrl)    
-
-
-    earthFit <- train(bbbDescr, logBBB,
-                      "earth",
-                      tuneLength = 10,
-                      trControl = ctrl)
-
-
-
-    bagEarthFit <- train(bbbDescr, logBBB,
-                         "bagEarth",
-                         tuneLength = 10,
-                         trControl = ctrl)
-
-    rfFit <- train(bbbDescr, logBBB,
-                   "rf",
-                   tuneLength = 5,
-                   trControl = ctrl)
-
-    crfFit <- train(bbbDescr, logBBB,
-                    "cforest",
-                    tuneLength = 5,
-                    trControl = ctrl)
-
-    gbmFit <- train(bbbDescr, logBBB,
-                    "gbm",
-                    tuneGrid = expand.grid(
-                      .interaction.depth = -1 + (1:5) * 2,
-                      .n.trees = 20 * (1:20),
-                      .shrinkage = .1),
-                    verbose = FALSE,
-                    bag.fraction = 0.9,
-                    trControl = ctrl)
-
-    svmRFit <- train(bbbDescr2, logBBB,
-                    "svmRadial",
-                    tuneLength = 5,
-                    trControl = ctrl)
-
-    svmLFit <- train(bbbDescr2, logBBB,
-                    "svmLinear",
-                    tuneLength = 5,
-                    trControl = ctrl)    
-
-    plsFit <- train(bbbDescr2, logBBB,
-                    "pls",
-                    tuneLength = 15,
-                    trControl = ctrl)
-
-
-    lmFit <- train(bbbDescr2, logBBB,
-                    "lm",
-                    trControl = ctrl)       
-    
-    cbFit <- train(bbbDescr2, logBBB,
-                    "cubist",
-                   tuneGrid = expand.grid(.committees = c(1:10, 20, 50, 75, 100), .neighbors = c(0, 1, 5, 9)),
-                    trControl = ctrl) 
-    resamps <- resamples(list(CART = rpartFit,
-                              CondInfTree = ctreeFit,
-                              MARS = earthFit,
-                              M5 = m5Fit,
-                              rf = rfFit,
-                              crf = crfFit,
-                              pls = plsFit,
-                              svmL = svmLFit,
-                              svmR = svmRFit,
-                              bagMARS = bagEarthFit,
-                              gbm = gbmFit,
-                              cubist = cbFit))
-    
-
-    save.image("bbb.RData")
-    resamps
-    bwplot(resamps, metric = "RMSE")
-    densityplot(resamps,
-                auto.key = list(columns = 3),
-                pch = "|")
-    splom(resamps, metric = "RMSE")
-
-    summary(resamps)
-    
-    difValues <- diff(resamps)
-
-    summary(difValues)
-
-    dotplot(difValues)
-    densityplot(difValues,
-                metric = "RMSE",
-                auto.key = TRUE,
-                pch = "|")
-
-    save(rpartFit, earthFit, ctreeFit, m5Fit, file = "~/tmp/exampleModels.RData")
-
-    ## add to caret web page and provide link
-
-  }
-
