@@ -42,6 +42,10 @@ byComplexity <- function(x, model)
            {
              x[order(x[,1], decreasing = TRUE),]
            },
+           rpartCost = 
+             {
+             x[order(-x$cp, -x$Cost),]
+             },
            M5Rules =
            {
              x$pruned <- factor(as.character(x$pruned), levels = c("Yes", "No"))
@@ -62,6 +66,10 @@ byComplexity <- function(x, model)
              # complex boundaries
              x[order(x$C, -x$sigma),]
            },
+           svmRadialWeights = 
+           {
+             x[order(x$C, -x$sigma, x$Weight),]
+           },           
            svmRadialCost =
            {
              x[order(x$C),]
@@ -212,6 +220,11 @@ byComplexity <- function(x, model)
              x$model <- factor(as.character(x$model), levels = c("rules", "tree"))
              x[order(x$trials, x$model, !x$winnow),]
            },
+           C5.0Cost = 
+           {
+             x$model <- factor(as.character(x$model), levels = c("rules", "tree"))
+             x[order(x$trials, x$model, !x$winnow, x$Cost),]
+           },           
            RRFglobal =, RRF = x[order(x$coefReg),],
            krlsRadial = x[order(x$lambda),],
            krlsPoly = x[order(x$degree, x$lambda),],
@@ -228,10 +241,10 @@ byComplexity <- function(x, model)
            sda = x[order(x$diagonal, x$lambda),],
            glmnet = x[order(-x$lambda, x$alpha),],
            stepLDA =, stepQDA = x[order(x$maxvar),],
-           GAMens = x[order(x$iter, x$rsm_size),],
            gam = x[order(x$select),],
            gamLoess =  x[order(x$degree, -x$span),],
            gamSpline =  x[order(x$df),],
+           protoclass = x[order(-x$eps),],
            stop("no sorting routine for this model")
            )
 
